"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.determineLocale = exports.default = void 0;

var _pluginError = _interopRequireDefault(require("plugin-error"));

var _through = _interopRequireDefault(require("through2"));

var _path = require("path");

var _vinylContentsTostring = _interopRequireDefault(require("vinyl-contents-tostring"));

var _i18nextConv = require("i18next-conv");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const PLUGIN_NAME = 'gulp-i18next-conv';

const defDetermineLocale = filename => filename.split(_path.sep)[0];

exports.determineLocale = defDetermineLocale;

function getConverter(file, gettextFormat) {
  switch ((0, _path.extname)(file.path)) {
    // file.extname doesn't work in older vinyl used by gulp 3
    case '.po':
    case '.pot':
    case '.mo':
      return [_i18nextConv.gettextToI18next, '.json'];

    case '.json':
      switch (gettextFormat) {
        case 'po':
          return [_i18nextConv.i18nextToPo, '.po'];

        case 'pot':
          return [_i18nextConv.i18nextToPot, '.pot'];

        case 'mo':
          return [_i18nextConv.i18nextToMo, '.mo'];

        default:
          throw new _pluginError.default(PLUGIN_NAME, 'Cannot determine which which file to convert to.');
      }

    default:
      throw new _pluginError.default(PLUGIN_NAME, 'Cannot determine which which file to convert to.');
  }
}

function getContents(file, data) {
  if (file.isBuffer()) {
    return Buffer.from(data);
  }

  if (file.isStream()) {
    const contents = (0, _through.default)();
    contents.write(data);
    contents.end();
    return contents;
  } // In case vinyl accepts new file types in the future


  throw new Error('Invalid file');
} // plugin level function (dealing with files)


function gulpGettextConv({
  determineLocale = defDetermineLocale,
  gettextFormat = 'po',
  ...options
} = {}) {
  // creating a stream through which each file will pass
  return _through.default.obj(function (file, enc, cb) {
    if (file.isNull()) {
      this.push(file);
      return cb();
    }

    let converter;
    let ext;

    try {
      [converter, ext] = getConverter(file, gettextFormat);
    } catch (err) {
      return cb(err);
    }

    return (0, _vinylContentsTostring.default)(file, enc).then(contents => {
      try {
        const domain = determineLocale(file.relative, contents);
        return converter(domain, contents, options);
      } catch (e) {
        throw new _pluginError.default(PLUGIN_NAME, 'determineLocale failed', {
          showStack: true
        });
      }
    }).then(data => {
      const path = (0, _path.join)((0, _path.dirname)(file.path), `${(0, _path.basename)(file.path, (0, _path.extname)(file.path))}${ext}`);
      Object.assign(file, {
        path,
        contents: getContents(file, data)
      }); // make sure the file goes through the next gulp plugin

      this.push(file);
      cb();
    }).catch(err => {
      cb(new _pluginError.default(PLUGIN_NAME, err.message));
    });
  });
} // exporting the plugin main function


var _default = gulpGettextConv;
exports.default = _default;